/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: turn.h,v 1.13 2008/05/15 19:58:29 bowkenken Exp $
***************************************************************/

#ifndef	TURN_H
#define	TURN_H

/***************************************************************
* 
***************************************************************/

/* θĴ */
#define	ADJUST_TURN	1

/* Υ */
#define	TURN_DAYTIME	(TURN_A_DAY / 2)

/* Υ */
#define	TURN_NIGHT	(TURN_A_DAY / 2)

/* Υ */
#define	TURN_A_DAY	(24 * TURN_PER_HOUR)

/* ֤Υ */
#define	TURN_PER_HOUR	(60 * TURN_PER_MINUTE)

/* ʬΥ */
#define	TURN_PER_MINUTE	(60 / SECOND_PER_TURN)

/* ÿ */
#define	SECOND_PER_TURN	10

/* νФλ */
#define	MORNING_HOUR	6

/* λ */
#define	EVENING_HOUR	17

/*  */
typedef enum {
	DAY_OF_WEEK_ELEC,
	DAY_OF_WEEK_PHYS,
	DAY_OF_WEEK_HEAT,
	DAY_OF_WEEK_COLD,
	DAY_OF_WEEK_WIND,
	DAY_OF_WEEK_ACID,
	DAY_OF_WEEK_POIS,
	DAY_OF_WEEK_MAX_N,
} day_of_week_t;

#endif	/* TURN_H */
